/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
/**
 * Importing global files to be added to global module of Node.js
 */
import '@athenna/ioc';
import '@athenna/config/src/Utils/global';
import { Application } from './Application';
export declare class Ignite {
    /**
     * Simple logger for Ignite class. Ignite creates a new
     * instance of Logger because providers are not registered
     * yet.
     *
     * @private
     */
    private logger;
    /**
     * An instance of the application. Is here that the
     * client will bootstrap his type of application.
     *
     * @private
     */
    private application;
    /**
     * The extension that is being used to bootstrap the
     * application. This will be usefully to preload files.
     *
     * @private
     */
    private extension;
    constructor(fileName: string);
    fire(): Promise<Application>;
    /**
     * Get the instance of the application inside of Ignite class.
     *
     * @return Application
     */
    getApplication(): Application;
    /**
     * Create a new instance of application inside
     * Ignite class.
     *
     * @return Application
     */
    private createApplication;
    /**
     * Resolve the NODE_TS Env variable verifying if the extension
     * of the file that is running Ignite class is .ts or other.
     *
     * @param fileName
     * @private
     */
    private resolveNodeTs;
    /**
     * Resolve the NODE_ENV Env variable verifying if it's already
     * set. If not, get the content of config/app file and take the
     * environment key value to set as NODE_ENV. Then, resolve the
     * .env.${NODE_ENV} file in Node.js process.
     *
     * @private
     */
    private resolveNodeEnv;
    /**
     * Clear the console if isn't in debug mode and NODE_ENV is
     * not set to testing environment.
     *
     * @private
     */
    private clearConsole;
    /**
     * Get all the providers from config/app file with export normalized.
     *
     * export default, export, module.exports, etc.
     *
     * @private
     */
    private getProviders;
    /**
     * Boot all the providers calling the boot method
     * and reading the register attributes inside providers.
     *
     * @private
     */
    private bootProviders;
    /**
     * Register all the providers calling the register method
     * and reading the register attributes inside providers.
     *
     * @private
     */
    private registerProviders;
    /**
     * Preload all the files configured inside config/app
     * file.
     *
     * @private
     */
    private preloadFiles;
}
